@@ -1,4 +1,4 @@
-use std::io::Cursor;
+use super::Cursor;
 
 use crate::msgpack::decode::*;
 
@@ -7,7 +7,7 @@ fn from_bool_false() {
     let buf = [0xc2];
     let mut cur = Cursor::new(&buf[..]);
 
-    assert_eq!(false, read_bool(&mut cur).unwrap());
+    assert!(!read_bool(&mut cur).unwrap());
     assert_eq!(1, cur.position());
 }
 
@@ -16,6 +16,6 @@ fn from_bool_true() {
     let buf = [0xc3];
     let mut cur = Cursor::new(&buf[..]);
 
-    assert_eq!(true, read_bool(&mut cur).unwrap());
+    assert!(read_bool(&mut cur).unwrap());
     assert_eq!(1, cur.position());
 }
